@@ -4,7 +4,6 @@ import os
 from datetime import datetime, timedelta, timezone
 from ffquant.utils.Logger import stdout_log
 import pytz
-import pandas_market_calendars as pmc
 
 __ALL__ = ['MyFeed']
 
@@ -36,27 +35,25 @@ class MyFeed(bt.feeds.DataBase):
         self.cache_data_list = []
         self.cur_index = 0
 
-        self.pmc = pmc.get_calendar(self.p.market)
-        start_date = datetime.strptime(self.p.start_time, '%Y-%m-%d %H:%M:%S').strftime('%Y-%m-%d')
-        end_date = datetime.strptime(self.p.end_time, '%Y-%m-%d %H:%M:%S').strftime('%Y-%m-%d')
-        self.schedule = self.pmc.schedule(start_date=start_date, end_date=end_date)
-
     def is_tradable(self, dt: datetime) -> bool:
         dt = dt.astimezone()
-
-        date_str = dt.strftime('%Y-%m-%d')
-        if date_str not in self.schedule.index:
+        if dt.weekday() == 6 or (dt.weekday() == 5 and dt.hour >= 3) or (dt.weekday() == 0 and dt.hour < 9):
             return False
 
-        open_time = self.schedule.loc[date_str]['market_open'].to_pydatetime().astimezone()
-        brk_start_time = self.schedule.loc[date_str]['break_start'].to_pydatetime().astimezone()
-        brk_end_time = self.schedule.loc[date_str]['break_end'].to_pydatetime().astimezone()
-        close_time = self.schedule.loc[date_str]['market_close'].to_pydatetime().astimezone()
+        # 星期六凌晨3点前的夜盘 允许
+        if dt.weekday() == 5 and dt.hour < 3:
+            return True
 
-        night_open_time = close_time.replace(hour=17, minute=30, second=0, microsecond=0)
-        night_close_time = close_time.replace(hour=3, minute=0, second=0, microsecond=0) + timedelta(days=1)
+        open_time = dt.replace(hour=9, minute=30, second=0, microsecond=0) - timedelta(minutes=15)
+        brk_start_time = dt.replace(hour=12, minute=0, second=0, microsecond=0)
+        brk_end_time = dt.replace(hour=13, minute=0, second=0, microsecond=0)
+        close_time = dt.replace(hour=16, minute=0, second=0, microsecond=0)
 
-        return dt < brk_start_time or brk_end_time <= dt < close_time or night_open_time <= dt < night_close_time
+        night_open_time = close_time.replace(hour=17, minute=30, second=0, microsecond=0) - timedelta(minutes=15)
+        night_close_time = close_time.replace(hour=3, minute=0, second=0, microsecond=0)    # 该日凌晨3点夜盘收盘时间
+        next_night_close_time = close_time.replace(hour=3, minute=0, second=0, microsecond=0) + timedelta(days=1)   # 次日凌晨3点夜盘收盘时间
+
+        return dt < night_close_time or open_time <= dt < brk_start_time or brk_end_time <= dt < close_time or night_open_time <= dt < next_night_close_time
 
     def start(self):
         super().start()
