@@ -7,7 +7,6 @@ import time
 import pytz
 import queue
 from ffquant.utils.Logger import stdout_log
-import pandas_market_calendars as pmc
 
 __ALL__ = ['MyLiveFeed']
 
@@ -34,10 +33,6 @@ class MyLiveFeed(bt.feeds.DataBase):
 
     def __init__(self):
         super(MyLiveFeed, self).__init__()
-        self.pmc = pmc.get_calendar(self.p.market)
-        start_date = datetime.now().strftime('%Y-%m-%d')
-        end_date = (datetime.now() + timedelta(days=1)).strftime('%Y-%m-%d')
-        self.schedule = self.pmc.schedule(start_date=start_date, end_date=end_date)
 
         self.brk_start_time = datetime.now().replace(hour=12, minute=0, second=0, microsecond=0).astimezone(pytz.utc)
         self.brk_end_time = datetime.now().replace(hour=13, minute=0, second=0, microsecond=0).astimezone(pytz.utc)
@@ -55,8 +50,31 @@ class MyLiveFeed(bt.feeds.DataBase):
         return True
 
     def is_tradable(self, dt: datetime) -> bool:
-        dt = dt.astimezone(pytz.utc)
-        return dt <= self.brk_start_time or self.brk_end_time < dt <= self.close_time or self.night_open_time < dt <= self.night_close_time
+        dt = dt.astimezone()
+
+        # MyLiveFeed中调用is_tradable时 传入的是k线的结束时间 这里需要计算出K线开始时间
+        if self.p.timeframe == bt.TimeFrame.Minutes:
+            dt = dt - timedelta(minutes=self.p.compression)
+        elif self.p.timeframe == bt.TimeFrame.Seconds:
+            dt = dt - timedelta(seconds=self.p.compression)
+
+        if dt.weekday() == 6 or (dt.weekday() == 5 and dt.hour >= 3) or (dt.weekday() == 0 and dt.hour < 9):
+            return False
+
+        # 星期六凌晨3点前的夜盘 允许
+        if dt.weekday() == 5 and dt.hour < 3:
+            return True
+
+        open_time = dt.replace(hour=9, minute=30, second=0, microsecond=0) - timedelta(minutes=15)
+        brk_start_time = dt.replace(hour=12, minute=0, second=0, microsecond=0)
+        brk_end_time = dt.replace(hour=13, minute=0, second=0, microsecond=0)
+        close_time = dt.replace(hour=16, minute=0, second=0, microsecond=0)
+
+        night_open_time = close_time.replace(hour=17, minute=30, second=0, microsecond=0) - timedelta(minutes=15)
+        night_close_time = close_time.replace(hour=3, minute=0, second=0, microsecond=0)    # 该日凌晨3点夜盘收盘时间
+        next_night_close_time = close_time.replace(hour=3, minute=0, second=0, microsecond=0) + timedelta(days=1)   # 次日凌晨3点夜盘收盘时间
+
+        return dt < night_close_time or open_time <= dt < brk_start_time or brk_end_time <= dt < close_time or night_open_time <= dt < next_night_close_time
 
     # start方法的调用先于next 但是start方法被调用时 strategy的minperiod还没有被确定 next方法被调用时 strategy的minperiod已经确定
     # 需要根据策略的minperiod来限制backfill_size 所以限制backfill_size需要在next方法中
@@ -255,8 +273,6 @@ class MyLiveFeed(bt.feeds.DataBase):
                 return True
             else:
                 retry_interval_s = 1
-                if self.p.timeframe == bt.TimeFrame.Seconds:
-                    retry_interval_s = 0.8
                 time.sleep(retry_interval_s)
 
         # 如果通过API没有获取到K线数据 那就尝试沿用前面的K线来充当
